@@ -1,30 +1,20 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the “Software”), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# Copyright © 2009-2021 Jakub Wilk <jwilk@jwilk.net>
+# SPDX-License-Identifier: MIT
 
 '''
 interface to AAlib, an ASCII art library
 '''
 
 import ctypes
+import sys
+
+type(b'')  # Python >= 2.6 is required
+
+if sys.version_info < (3,):
+    import __builtin__ as builtins  # pylint: disable=import-error
+    range = builtins.xrange  # pylint: disable=redefined-builtin
 
 libaa = ctypes.CDLL('libaa.so.1')
 
@@ -40,7 +30,6 @@ class Structure(ctypes.Structure):
         return clone
 
 class HardwareSettings(Structure):
-    _pack_ = 4
     _fields_ = [
         ('font', FontPtr),
         ('options', ctypes.c_int),
@@ -77,7 +66,6 @@ ATTRIBUTE_REVERSE = 4
 DEFAULT_HARDWARE_SETTINGS = HardwareSettings.in_dll(libaa, 'aa_defparams')
 
 class RenderSettings(Structure):
-    _pack_ = 4
     _fields_ = [
         ('brightness', ctypes.c_int),
         ('contrast', ctypes.c_int),
@@ -171,7 +159,7 @@ class Screen(object):
         - `bold_value`.
         '''
         settings = self._get_default_settings()
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             setattr(settings, k, v)
         context = self._context = aa_init(ctypes.pointer(aa_mem_d), ctypes.pointer(settings), None)
         if context is None:
@@ -230,9 +218,9 @@ class Screen(object):
         virtual_height = self._virtual_height
         (x0, y0) = xy
         (image_width, image_height) = image.size
-        for y in xrange(max(y0, 0), min(y0 + image_height, virtual_height)):
+        for y in range(max(y0, 0), min(y0 + image_height, virtual_height)):
             p = y * virtual_width
-            for x in xrange(max(x0, 0), min(x0 + image_width, virtual_width)):
+            for x in range(max(x0, 0), min(x0 + image_width, virtual_width)):
                 self._framebuffer[p + x] = image.getpixel((x - x0, y - y0))
 
     def __getitem__(self, xy):
@@ -252,7 +240,7 @@ class Screen(object):
         - `random`.
         '''
         settings = DEFAULT_RENDER_SETTINGS.clone()
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             setattr(settings, k, v)
         context = self._context
         buffer = aa_image(context)
@@ -265,9 +253,9 @@ class Screen(object):
         return [
             [
                 (chr(text[y * width + x]), attrs[y * width + x])
-                for x in xrange(width)
+                for x in range(width)
             ]
-            for y in xrange(height)
+            for y in range(height)
         ]
 
     def __del__(self):
@@ -298,7 +286,7 @@ class AnsiScreen(AsciiScreen):
 
     _formats = {
         ATTRIBUTE_NORMAL: '{s}',
-        ATTRIBUTE_BRIGHT: '\x1b[1m{s}\x1b[0m',
+        ATTRIBUTE_BRIGHT: '\x1B[1m{s}\x1B[0m',
     }
 
     def _get_default_settings(self):
@@ -312,9 +300,9 @@ class LinuxScreen(AsciiScreen):
 
     _formats = {
         ATTRIBUTE_NORMAL: '{s}',
-        ATTRIBUTE_BOLD: '\x1b[1m{s}\x1b[0m',
-        ATTRIBUTE_DIM: '\x1b[30;1m{s}\x1b[0m',
-        ATTRIBUTE_REVERSE: '\x1b[7m{s}\x1b[0m',
+        ATTRIBUTE_BOLD: '\x1B[1m{s}\x1B[0m',
+        ATTRIBUTE_DIM: '\x1B[30;1m{s}\x1B[0m',
+        ATTRIBUTE_REVERSE: '\x1B[7m{s}\x1B[0m',
     }
 
     def _get_default_settings(self):
